aboutsummaryrefslogtreecommitdiff
path: root/libs/nak/src
diff options
context:
space:
mode:
Diffstat (limited to 'libs/nak/src')
-rw-r--r--libs/nak/src/paths.rs7
1 files changed, 3 insertions, 4 deletions
diff --git a/libs/nak/src/paths.rs b/libs/nak/src/paths.rs
index 4b212b9..e86c284 100644
--- a/libs/nak/src/paths.rs
+++ b/libs/nak/src/paths.rs
@@ -1,12 +1,11 @@
//! Shared data directory for Fluorine Manager.
//!
-//! All data lives under `~/.local/share/fluorine/` — accessible from both
-//! native and Flatpak builds (the Flatpak has `--filesystem=home`).
+//! All data lives under `~/.var/app/com.fluorine.manager/`.
use std::path::PathBuf;
/// Returns the Fluorine data directory (`~/.local/share/fluorine`).
pub fn data_dir() -> PathBuf {
let home = std::env::var("HOME").unwrap_or_else(|_| "/tmp".to_string());
- PathBuf::from(home).join(".local/share/fluorine")
+ PathBuf::from(home).join(".var/app/com.fluorine.manager")
}
@@ -1,12 +1,11 @@
use std::path::PathBuf;
-/// Returns the Fluorine data directory (`~/.local/share/fluorine`).
+/// Returns the Fluorine data directory (`~/.var/app/com.fluorine.manager`).
pub fn data_dir() -> PathBuf {
let home = std::env::var("HOME").unwrap_or_else(|_| "/tmp".to_string());